import { webcrypto } from "crypto"

declare module "crypto" {
  export const webcrypto: Crypto
}

async function pbkdf2(password: string, salt: string, iterations = 1000, length = 256) {
  const encoder = new TextEncoder()
  const key = await webcrypto.subtle.importKey(
    "raw",
    encoder.encode(password),
    "PBKDF2",
    false,
    ["deriveBits"]
  )
  const bits = await webcrypto.subtle.deriveBits(
    {
      name: "PBKDF2",
      hash: "SHA-512",
      salt: encoder.encode(salt),
      iterations,
    },
    key,
    length
  )
  return bits
}
